searchNodes=[{"ref":"RedMutex.html","title":"RedMutex","module":"RedMutex","type":"behaviour","doc":"Defines a mutex. A mutex defines an easy to use interface to interact with an distributed lock backed by redis. When used, the mutex expects the :otp_app as option. The :otp_app should point to an OTP application that has the mutex configuration. For example, the mutex: defmodule MyApp.MyMutex do use RedMutex, otp_app: :my_app end Could be configured with: config :my_app, MyApp.MyMutex, url: &quot;redis://localhost:6379&quot;, key: &quot;red_mutex_lock&quot;, expiration_in_seconds: 3_600 Options: :url - the redis url. Required. :key- The key at redis used to store the lock information. Defaults to &quot;red_mutex_lock&quot;. :expiration_in_seconds - Time in seconds that the resource will be kept locked. After that time the lock will be automattically released. Defaults to 3600, one hour."},{"ref":"RedMutex.html#c:acquire_lock/0","title":"RedMutex.acquire_lock/0","module":"RedMutex","type":"callback","doc":"Attempts to acquire an lock. Examples iex&gt; MyMutex.acquire_lock() {:ok, lock} iex&gt; MyMutex.acquire_lock() {:error, :already_locked} iex&gt; MyMutex.acquire_lock() {:error, reason}"},{"ref":"RedMutex.html#c:exists_lock/0","title":"RedMutex.exists_lock/0","module":"RedMutex","type":"callback","doc":"Checks if an lock exists. Returns {:ok, true} if the resource is locked. Examples iex&gt; MyMutex.exists_lock() {:ok, true} iex&gt; MyMutex.exists_lock() {:ok, false} iex&gt; MyMutex.exists_lock() {:error, reason}"},{"ref":"RedMutex.html#c:release_lock/1","title":"RedMutex.release_lock/1","module":"RedMutex","type":"callback","doc":"Releases the lock. Examples iex&gt; MyMutex.release_lock(lock) :ok iex&gt; MyMutex.release_lock(lock) {:error, :unlock_fail} iex&gt; MyMutex.release_lock(lock) {:error, reason}"},{"ref":"RedMutex.html#c:synchronize/1","title":"RedMutex.synchronize/1","module":"RedMutex","type":"callback","doc":"Obtains an lock, run the callback, and releases the lock when the block completes. Examples iex&gt; MyMutex.synchronize(fn -&gt; ...&gt; # work ...&gt; {:ok, &quot;completed&quot;} ...&gt; end) {:ok, &quot;completed&quot;} iex&gt; MyMutex.synchronize({MyApp, :work, []}) {:ok, &quot;completed&quot;}"},{"ref":"RedMutex.html#t:callback/0","title":"RedMutex.callback/0","module":"RedMutex","type":"type","doc":""},{"ref":"RedMutex.html#t:lock/0","title":"RedMutex.lock/0","module":"RedMutex","type":"type","doc":""},{"ref":"RedMutex.html#t:reason/0","title":"RedMutex.reason/0","module":"RedMutex","type":"type","doc":""},{"ref":"readme.html","title":"RedMutex","module":"readme","type":"extras","doc":"RedMutex RedMutex defines an easy to use interface to control an distributed lock backed by redis."},{"ref":"readme.html#installation","title":"RedMutex - Installation","module":"readme","type":"extras","doc":"The package can be installed by adding red_mutex to your list of dependencies in mix.exs: def deps do [ {:red_mutex, &quot;~&gt; 0.2.2&quot;} ] end The docs can be found at https://hexdocs.pm/red_mutex."},{"ref":"readme.html#usage","title":"RedMutex - Usage","module":"readme","type":"extras","doc":"# In your config/config.exs file config :my_app, MyApp.MyMutex, url: &quot;redis://localhost:6379&quot;, key: &quot;red_mutex_lock&quot;, expiration_in_seconds: 3_600 # In your application code defmodule MyApp.MyMutex do use RedMutex, otp_app: :my_app end defmodule MyApp do import RedMutex, only: [synchronize: 1] alias MyApp.MyMutex def syncronized_work do synchronize({__MODULE__, :work, []}) end def lock_unlock do case MyMutex.acquire_lock() do {:ok, lock} -&gt; work() MyMutex.release_lock(lock) {:error, reason} -&gt; {:error, reason} end end def work do # do some work {:ok, &quot;completed&quot;} end end"},{"ref":"readme.html#contributing","title":"RedMutex - Contributing","module":"readme","type":"extras","doc":"See the contributing file."},{"ref":"readme.html#license","title":"RedMutex - License","module":"readme","type":"extras","doc":"Apache License, Version 2.0 © Thiago Santos"}]